introspectiontools
==================

.. automodule:: abjad.tools.introspectiontools

.. only:: html

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.introspectiontools.class_to_tools_package_qualified_class_name.class_to_tools_package_qualified_class_name
      ~abjad.tools.introspectiontools.get_current_function_name.get_current_function_name
